==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/include/util/require.h <==
/*
   Copyright (c) 2021, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef NDB_UTIL_REQUIRE_H
#define NDB_UTIL_REQUIRE_H

#include "my_compiler.h" // likely

/*
 * require is like a normal assert, only it's always on (eg. in release)
 */
[[noreturn]] void require_failed(int exitcode,
                                 const char* expr,
                                 const char* file,
                                 int line);
/*
 *  this allows for an exit() call if exitcode is not zero
*/
#define require_exit_or_core(v, exitcode) \
  do { if (likely(!(!(v)))) break; \
       require_failed((exitcode), #v, __FILE__, __LINE__); \
  } while (0)

/*
 * this require is like a normal assert.  (only it's always on)
*/
#define require(v) require_exit_or_core((v), 0)

#endif

==> percona-xtrabackup-8.3.0-1.tar.gz: percona-xtrabackup-8.3.0-1/storage/ndb/include/util/require.h <==
/*
   Copyright (c) 2021, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef NDB_UTIL_REQUIRE_H
#define NDB_UTIL_REQUIRE_H

#include "my_compiler.h"  // likely

/*
 * require is like a normal assert, only it's always on (eg. in release)
 */
[[noreturn]] void require_failed(int exitcode, const char *expr,
                                 const char *file, int line);
/*
 *  this allows for an exit() call if exitcode is not zero
 */
#define require_exit_or_core(v, exitcode)               \
  do {                                                  \
    if (likely(!(!(v)))) break;                         \
    require_failed((exitcode), #v, __FILE__, __LINE__); \
  } while (0)

/*
 * this require is like a normal assert.  (only it's always on)
 */
#define require(v) require_exit_or_core((v), 0)

#endif
